pub fn shadow_root_style_data_equals<S>(l: Option<S>, r: Option<S>) -> boolwhere
S: TShadowRoot,Expand description
Returns whether the cascade data of the given shadow roots is the same.
pub fn shadow_root_style_data_equals<S>(l: Option<S>, r: Option<S>) -> boolwhere
S: TShadowRoot,Returns whether the cascade data of the given shadow roots is the same.